##
##  fontconfig.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         fontconfig
Summary:      Font Access Configuration And Customizing
URL:          http://fontconfig.org/
Vendor:       Keith Packard
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        XWindow
License:      GPL
Version:      2.15.0
Release:      20231222

#   list of sources
Source0:      http://fontconfig.org/release/fontconfig-%{version}.tar.gz
Patch0:       fontconfig.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, make, gcc, grep, pkgconfig, gperf
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  libiconv, freetype, expat, libxml, libuuid
PreReq:       libiconv, freetype, expat, libxml, libuuid

%description
    Fontconfig is a library for configuring and customizing font access.
    It contains two essential modules, the configuration module which
    builds an internal configuration from XML files and the matching
    module which accepts font patterns and returns the nearest matching
    font.

%track
    prog fontconfig = {
        version   = %{version}
        url       = http://fontconfig.org/release/
        regex     = fontconfig-(\d+\.\d+\.\d+)\.tar\.gz
    }

%prep
    %setup -q
    %patch -p0

%build
    ( echo 'ac_cv_prog_HASDOCBOOK=${ac_cv_prog_HASDOCBOOK=no}'
    ) >config.cache
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags e2fs .}" \
    LDFLAGS="%{l_ldflags}" \
    LIBS="-liconv" \
    GREP="grep" \
    ITSTOOL="true" \
    ./configure \
        --cache-file=./config.cache \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --with-expat=%{l_prefix} \
        --with-baseconfigdir=%{l_prefix}/etc/fontconfig \
        --with-cache-dir=%{l_prefix}/var/fontconfig \
        --disable-nls \
        --disable-docs \
        --disable-shared
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    rm -f $RPM_BUILD_ROOT%{l_prefix}/etc/fontconfig/conf.d/48-spacing.conf
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/doc >/dev/null 2>&1 || true
    strip  $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/fontconfig/*.conf' \
        '%config %{l_prefix}/etc/fontconfig/conf.d/*.conf'

%files -f files

%clean

%post
    #   update fontconfig cache
    $RPM_INSTALL_PREFIX/bin/fc-cache -f 2>/dev/null || true
    exit 0

